# purge_haplotigs

**DOI:** [10.5281/zenodo.14967449](https://doi.org/10.5281/zenodo.14967449)

## Available Versions
- **Version 1.1.3**
  - [Download](https://zenodo.org/record/14967450/files/purge_haplotigs_1.1.3.img)
  - **MD5:** `ea973cae3f075bc8f7f9c02b1f0fbe01`
  - **DOI:** [10.5281/zenodo.14967450](https://doi.org/10.5281/zenodo.14967450)
  - **Size:** 161.69 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```purge_haplotigs```
